@@ -5,8 +5,6 @@ import difflib
 import os
 from typing import NamedTuple
 
-from colorama import Fore
-
 from autobot.transforms import TransformType
 
 BEFORE_FILENAME: str = "before.py"
@@ -19,22 +17,18 @@ class SchematicDefinitionException(Exception):
 
 def extract_transform_type(source_code: str) -> TransformType | None:
     for node in ast.walk(ast.parse(source_code)):
-        if isinstance(node, (ast.FunctionDef, ast.AsyncFunctionDef)):
-            return TransformType.FUNCTION
-
-        if isinstance(node, ast.ClassDef):
-            return TransformType.CLASS
+        for transform_type in TransformType:
+            if isinstance(node, transform_type.ast_node_type()):
+                return transform_type
     else:
         return None
 
 
 def extract_source(source_code: str) -> str | None:
     for node in ast.walk(ast.parse(source_code)):
-        if isinstance(node, (ast.FunctionDef, ast.AsyncFunctionDef)):
-            return ast.get_source_segment(source_code, node)
-
-        if isinstance(node, ast.ClassDef):
-            return ast.get_source_segment(source_code, node)
+        for transform_type in TransformType:
+            if isinstance(node, transform_type.ast_node_type()):
+                return ast.get_source_segment(source_code, node)
     else:
         return None
 
@@ -56,7 +50,7 @@ class Schematic(NamedTuple):
     transform_type: TransformType
 
     @classmethod
-    def from_directory(cls, dirname: str) -> "Schematic":
+    def from_directory(cls, dirname: str) -> Schematic:
         """Load a Schematic from a directory."""
         dirname = dirname.rstrip("/")
         title = os.path.basename(dirname)
@@ -121,6 +115,8 @@ class Schematic(NamedTuple):
         )
 
     def print_diff(self) -> None:
+        from colorama import Fore
+
         for line in difflib.unified_diff(
             self.before_text.splitlines(),
             self.after_text.splitlines(),
