@@ -5,14 +5,26 @@ import re
 from typing import Generator, NamedTuple, Type
 
 
-def decontextualize(source: str, node: ast.stmt) -> "Snippet":
+class Snippet(NamedTuple):
+    """A snippet extracted from source code."""
+
+    text: str
+    padding: str
+    lineno: int
+
+    @classmethod
+    def from_node(cls, source_code: str, node: ast.AST) -> Snippet:
+        return decontextualize(source_code, node)
+
+
+def decontextualize(source_code: str, node: ast.AST) -> Snippet:
     """Decontextualize a snippet from its originating source code.
 
     Takes the originating source code as input, along with the node to decontextualize,
     and extracts the code as a snippet, removing any indentation.
     """
     # Extract the source segment.
-    source_segment = ast.get_source_segment(source, node, padded=True)
+    source_segment = ast.get_source_segment(source_code, node, padded=True)
     assert source_segment, "Unable to find source segment."
 
     # Dedent the code:.
@@ -28,7 +40,7 @@ def decontextualize(source: str, node: ast.stmt) -> "Snippet":
     return Snippet(source_segment, padding, node.lineno)
 
 
-def recontextualize(snippet: "Snippet", source: str) -> list[str]:
+def recontextualize(snippet: Snippet, source_code: str) -> list[str]:
     """Recontextualize a snippet within its originating source code.
 
     Takes the originating source code and snippet as input, and outputs the lines of the
@@ -38,7 +50,7 @@ def recontextualize(snippet: "Snippet", source: str) -> list[str]:
     lines: list[str] = []
 
     # Prepend any lines of the originating source code that precede the snippet.
-    source_lines = source.splitlines()
+    source_lines = source_code.splitlines()
     if snippet.lineno > 1:
         for i in range(snippet.lineno - 1):
             lines.append(source_lines[i])
@@ -50,56 +62,15 @@ def recontextualize(snippet: "Snippet", source: str) -> list[str]:
     return lines
 
 
-class Snippet(NamedTuple):
-    """A snippet extracted from source code."""
-
-    text: str
-    padding: str
-    lineno: int
-
-    @classmethod
-    def from_node(cls, source: str, node: ast.stmt) -> "Snippet":
-        return decontextualize(source, node)
-
-
-class ClassDefVisitor(ast.NodeVisitor):
-    """NodeVisitor to collect all ClassDef nodes in an AST."""
-
-    def __init__(self) -> None:
-        self.nodes: list[ast.ClassDef] = []
-
-    def visit_ClassDef(self, node: ast.ClassDef) -> None:
-        self.nodes.append(node)
-
-
-class FunctionDefVisitor(ast.NodeVisitor):
-    """NodeVisitor to collect all FunctionDef nodes in an AST."""
-
-    def __init__(self) -> None:
-        self.nodes: list[ast.FunctionDef] = []
-
-    def visit_FunctionDef(self, node: ast.FunctionDef) -> None:
-        self.nodes.append(node)
-
-
 def iter_snippets(
-    source: str,
-    node_type: Type[ast.stmt],
+    source_code: str,
+    node_type: Type[ast.AST] | tuple[Type[ast.AST], ...],
 ) -> Generator[Snippet, None, None]:
     """Generate all snippets from the provided source code.
 
     Returns: a tuple of (text to fix, any indentation that was removed from the
         snippet, line number in the source file).
     """
-    visitor: ClassDefVisitor | FunctionDefVisitor
-    if node_type == ast.ClassDef:
-        visitor = ClassDefVisitor()
-    elif node_type == ast.FunctionDef:
-        visitor = FunctionDefVisitor()
-    else:
-        raise NotImplementedError(f"Unhandled AST node type: {node_type}")
-
-    visitor.visit(ast.parse(source))
-
-    for node in visitor.nodes:
-        yield Snippet.from_node(source, node)
+    for node in ast.walk(ast.parse(source_code)):
+        if isinstance(node, node_type):
+            yield Snippet.from_node(source_code, node)
